# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: models/runtime/stack.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='models/runtime/stack.proto',
  package='runtime',
  syntax='proto3',
  serialized_options=b'Z\"go.jetpack.io/axiom/models/runtime',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1amodels/runtime/stack.proto\x12\x07runtime*7\n\x05Stack\x12\x0e\n\nSTACK_NONE\x10\x00\x12\n\n\x06PYTHON\x10\x01\x12\x06\n\x02GO\x10\x02\x12\n\n\x06NODEJS\x10\x03\x42$Z\"go.jetpack.io/axiom/models/runtimeb\x06proto3'
)

_STACK = _descriptor.EnumDescriptor(
  name='Stack',
  full_name='runtime.Stack',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STACK_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PYTHON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NODEJS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=39,
  serialized_end=94,
)
_sym_db.RegisterEnumDescriptor(_STACK)

Stack = enum_type_wrapper.EnumTypeWrapper(_STACK)
STACK_NONE = 0
PYTHON = 1
GO = 2
NODEJS = 3


DESCRIPTOR.enum_types_by_name['Stack'] = _STACK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
